import * as apigateway from 'aws-cdk-lib/aws-apigateway';
import * as iam from 'aws-cdk-lib/aws-iam';
import * as r53 from 'aws-cdk-lib/aws-route53';
import { Construct } from 'constructs';
import { Allocate } from '../allocate';
import { Deallocate } from '../deallocate';
/**
 * Options for `Endpoint`.
 */
export interface EndpointOptions {
    /**
     * List of principals that are allowed to access the endpoint.
     *
     * @default - endpoint is not accessible by anyone.
     */
    readonly allowedPrincipals?: iam.ArnPrincipal[];
    /**
     * Hosted zone that provides DNS resolution for the endpoint custom domain.
     * Domain FQDN will be the same as the hosted zone name.
     *
     * If this not specified, a custom domain will not be created. Note that since
     * the default execute-api endpoint is disabled, this will render the service
     * inaccessible for HTTP calls.
     *
     * @default - no custom domain is created and the service endpoint is not accessible.
     */
    readonly hostedZone?: r53.IHostedZone;
}
/**
 * Properties `Endpoint`.
 */
export interface EndpointProps extends EndpointOptions {
    /**
     * Allocate function.
     */
    readonly allocate: Allocate;
    /**
     * Deallocate function.
     */
    readonly deallocate: Deallocate;
}
export declare class Endpoint extends Construct {
    /**
     * Api Gateway rest api.
     */
    readonly api: apigateway.RestApi;
    /**
     * Allocations sub resource.
     */
    readonly allocationsResource: apigateway.Resource;
    /**
     * Allocation sub resource.
     */
    readonly allocationResource: apigateway.Resource;
    constructor(scope: Construct, id: string, props: EndpointProps);
    private denyAllPolicy;
    private allowOnlyPolicy;
}
